@@ -16,11 +16,11 @@ Config::Abstraction - Configuration Abstraction Layer
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 SYNOPSIS
 
@@ -335,7 +335,7 @@ sub _load_config
 						if(($data = LoadFile($path)) && (ref($data) eq 'HASH')) {
 							# Could be colon file, could be YAML, whichever it is, break the configuration fields
 							# foreach my($k, $v) (%{$data}) {
-							foreach my($k) (keys %{$data}) {
+							foreach my $k (keys %{$data}) {
 								my $v = $data->{$k};
 								next if($v =~ /^".+"$/);	# Quotes to keep in one field
 								if($v =~ /,/) {
